[gnome-software: 2/2] Merge branch '720-rename-remove-to-uninstall' into 'master'




commit ab6fb45a2ac57cc5a9bdbeff5eadfe8a1b22cc91
Merge: daf77d4c2 2418ac446
Author: Phaedrus Leeds <mwl458 gmail com>
Date:   Fri Jan 15 05:02:39 2021 +0000

    Merge branch '720-rename-remove-to-uninstall' into 'master'
    
    ui: Rename ‘Remove’ to ‘Uninstall’
    
    See merge request GNOME/gnome-software!522

 src/gs-app-row.c        |  6 +++---
 src/gs-details-page.c   |  2 +-
 src/gs-details-page.ui  |  2 +-
 src/gs-history-dialog.c |  4 ++--
 src/gs-page.c           | 14 +++++++-------
 tests/basic.py          |  6 +++---
 6 files changed, 17 insertions(+), 17 deletions(-)
---
diff --cc src/gs-app-row.c
index b523f1bee,3e81d36a7..f4e97d77a
--- a/src/gs-app-row.c
+++ b/src/gs-app-row.c
@@@ -154,18 -154,18 +154,18 @@@ gs_app_row_refresh_button (GsAppRow *ap
                } else {
                        /* TRANSLATORS: this is a button next to the search results that
                         * allows the application to be easily removed */
-                       gtk_button_set_label (GTK_BUTTON (priv->button), _("Remove"));
+                       gtk_button_set_label (GTK_BUTTON (priv->button), _("Uninstall"));
                }
                break;
 -      case AS_APP_STATE_UPDATABLE:
 -      case AS_APP_STATE_INSTALLED:
 +      case GS_APP_STATE_UPDATABLE:
 +      case GS_APP_STATE_INSTALLED:
                if (!gs_app_has_quirk (priv->app, GS_APP_QUIRK_COMPULSORY))
                        gtk_widget_set_visible (priv->button, TRUE);
                /* TRANSLATORS: this is a button next to the search results that
                 * allows the application to be easily removed */
-               gtk_button_set_label (GTK_BUTTON (priv->button), _("Remove"));
+               gtk_button_set_label (GTK_BUTTON (priv->button), _("Uninstall"));
                break;
 -      case AS_APP_STATE_INSTALLING:
 +      case GS_APP_STATE_INSTALLING:
                gtk_widget_set_visible (priv->button, TRUE);
                /* TRANSLATORS: this is a button next to the search results that
                 * shows the status of an application being installed */
diff --cc src/gs-details-page.c
index e74b47861,2d6fefa05..4123ed98d
--- a/src/gs-details-page.c
+++ b/src/gs-details-page.c
@@@ -985,15 -1010,15 +985,15 @@@ gs_details_page_refresh_buttons (GsDeta
                        else
                                gtk_style_context_add_class (gtk_widget_get_style_context 
(self->button_remove), "destructive-action");
                        /* TRANSLATORS: button text in the header when an application can be erased */
-                       gtk_button_set_label (GTK_BUTTON (self->button_remove), _("_Remove"));
+                       gtk_button_set_label (GTK_BUTTON (self->button_remove), _("_Uninstall"));
                        break;
 -              case AS_APP_STATE_AVAILABLE_LOCAL:
 -              case AS_APP_STATE_AVAILABLE:
 -              case AS_APP_STATE_INSTALLING:
 -              case AS_APP_STATE_REMOVING:
 -              case AS_APP_STATE_UNAVAILABLE:
 -              case AS_APP_STATE_UNKNOWN:
 -              case AS_APP_STATE_QUEUED_FOR_INSTALL:
 +              case GS_APP_STATE_AVAILABLE_LOCAL:
 +              case GS_APP_STATE_AVAILABLE:
 +              case GS_APP_STATE_INSTALLING:
 +              case GS_APP_STATE_REMOVING:
 +              case GS_APP_STATE_UNAVAILABLE:
 +              case GS_APP_STATE_UNKNOWN:
 +              case GS_APP_STATE_QUEUED_FOR_INSTALL:
                        gtk_widget_set_visible (self->button_remove, FALSE);
                        break;
                default:
diff --cc src/gs-history-dialog.c
index bdee1d9f4,071c8a8ca..4b1ae57aa
--- a/src/gs-history-dialog.c
+++ b/src/gs-history-dialog.c
@@@ -63,14 -63,14 +63,14 @@@ gs_history_dialog_set_app (GsHistoryDia
  
                /* add the action */
                switch (gs_app_get_state (app)) {
 -              case AS_APP_STATE_AVAILABLE:
 -              case AS_APP_STATE_REMOVING:
 +              case GS_APP_STATE_AVAILABLE:
 +              case GS_APP_STATE_REMOVING:
                        /* TRANSLATORS: this is the status in the history UI,
-                        * where we are showing the application was removed */
-                       tmp = C_("app status", "Removed");
+                        * where we are showing the application was uninstalled */
+                       tmp = C_("app status", "Uninstalled");
                        break;
 -              case AS_APP_STATE_INSTALLED:
 -              case AS_APP_STATE_INSTALLING:
 +              case GS_APP_STATE_INSTALLED:
 +              case GS_APP_STATE_INSTALLING:
                        /* TRANSLATORS: this is the status in the history UI,
                         * where we are showing the application was installed */
                        tmp = C_("app status", "Installed");


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]